@@ -1,14 +1,12 @@
 from .__version__ import __version__
 
-__all__ = ['__version__']
+__all__ = ["__version__"]
 
 from . import afit
-from . import beam
+from . import dpc
 from . import eels
 from . import gpa
 from . import nbed
-from . import proc
-from . import util
-from . import dpc
 from . import sim
-from .code_timer import *
+from . import util
+from .timer import *
